==> packageinstaller-pkglist_0.3.30.tar.xz: packageinstaller-pkglist/mpd.pm <==
<?xml version="1.0"?>
<app>

<category>
Audio
</category>

<name>
MPD Music Player Daemon
</name>

<description>
   <am>a flexible, powerful, server-side application for playing music</am>
   <ar>a flexible, powerful, server-side application for playing music</ar>
   <be>a flexible, powerful, server-side application for playing music</be>
   <bg>a flexible, powerful, server-side application for playing music</bg>
   <bn>a flexible, powerful, server-side application for playing music</bn>
   <ca>aplicació flexible i potent de servidor per reproduir música</ca>
   <cs>a flexible, powerful, server-side application for playing music</cs>
   <da>et fleksibelt, kraftfuldt, server-side-program til at afspille musik</da>
   <de>Eine flexible, leistungsfähige, serverseitige Anwendung zum Abspielen von Musik</de>
   <el>Ευέλικτη, ισχυρή εφαρμογή διακομιστή για αναπαραγωγή μουσικής</el>
   <en>a flexible, powerful, server-side application for playing music</en>
   <es_ES>Servidor de reproducción de música flexible y potente</es_ES>
   <es>Servidor de reproducción de música flexible y potente</es>
   <et>a flexible, powerful, server-side application for playing music</et>
   <eu>a flexible, powerful, server-side application for playing music</eu>
   <fa>a flexible, powerful, server-side application for playing music</fa>
   <fil_PH>a flexible, powerful, server-side application for playing music</fil_PH>
   <fi>joustava, tehokas, palvelinpuolen sovellus musiikinsoittamiseen</fi>
   <fr_BE>Une application server-side souple et puissante pour lire de la musique</fr_BE>
   <fr>Une application server-side souple et puissante pour lire de la musique</fr>
   <gl_ES>Aplicativo de servidor, flexible e poderosa, para reprodución de música</gl_ES>
   <he_IL>a flexible, powerful, server-side application for playing music</he_IL>
   <hi>a flexible, powerful, server-side application for playing music</hi>
   <hr>a flexible, powerful, server-side application for playing music</hr>
   <hu>a flexible, powerful, server-side application for playing music</hu>
   <id>a flexible, powerful, server-side application for playing music</id>
   <is>a flexible, powerful, server-side application for playing music</is>
   <it>è un'applicazione lato server, flessibile e potente, per la la riproduzione di file musicali</it>
   <ja>音楽を再生用の柔軟で強力なサーバーサイド・アプリケーション</ja>
   <kk>a flexible, powerful, server-side application for playing music</kk>
   <ko>a flexible, powerful, server-side application for playing music</ko>
   <lt>a flexible, powerful, server-side application for playing music</lt>
   <mk>a flexible, powerful, server-side application for playing music</mk>
   <mr>a flexible, powerful, server-side application for playing music</mr>
   <nb_NO>a flexible, powerful, server-side application for playing music</nb_NO>
   <nb>fleksibel og kraftig lydavspiller på tjenersiden</nb>
   <nl_BE>a flexible, powerful, server-side application for playing music</nl_BE>
   <nl>een flexibele, krachtige applicatie aan de serverzijde voor het afspelen van muziek</nl>
   <pl>elastyczna, potężna aplikacja po stronie serwera do odtwarzania muzyki</pl>
   <pt_BR>Aplicativo flexível e poderoso do lado do servidor para reproduzir música</pt_BR>
   <pt>Aplicação de servidor, flexível e poderosa, para reprodução de música</pt>
   <ro>a flexible, powerful, server-side application for playing music</ro>
   <ru>Гибкое многофункциональное приложение для воспроизведения музыки</ru>
   <sk>a flexible, powerful, server-side application for playing music</sk>
   <sl>Prilagodljiv in zmogljiv strežniški program za predvajanje glasbe</sl>
   <sq>a flexible, powerful, server-side application for playing music</sq>
   <sr>a flexible, powerful, server-side application for playing music</sr>
   <sv>en flexibel, kraftfull server-applikation för att spela upp musik</sv>
   <th>a flexible, powerful, server-side application for playing music</th>
   <tr>müzik çalmak için esnek, güçlü, sunucu taraflı bir uygulama</tr>
   <uk>гнучка. потужна програма на боці сервера для програвання музики</uk>
   <vi>a flexible, powerful, server-side application for playing music</vi>
   <zh_CN>a flexible, powerful, server-side application for playing music</zh_CN>
   <zh_HK>a flexible, powerful, server-side application for playing music</zh_HK>
   <zh_TW>a flexible, powerful, server-side application for playing music</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
mpd
mpc
mpdscribble
ncmpcpp
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
mpd
mpc
mpdscribble
ncmpcpp
</uninstall_package_names>
</app>

==> packageinstaller-pkglist_0.3.32.tar.xz: packageinstaller-pkglist/mpd.pm <==
<?xml version="1.0"?>
<app>

<category>
Audio
</category>

<name>
MPD Music Player Daemon
</name>

<description>
   <am>a flexible, powerful, server-side application for playing music</am>
   <ar>a flexible, powerful, server-side application for playing music</ar>
   <be>a flexible, powerful, server-side application for playing music</be>
   <bg>a flexible, powerful, server-side application for playing music</bg>
   <bn>a flexible, powerful, server-side application for playing music</bn>
   <ca>aplicació flexible i potent de servidor per reproduir música</ca>
   <cs>a flexible, powerful, server-side application for playing music</cs>
   <da>et fleksibelt, kraftfuldt, server-side-program til at afspille musik</da>
   <de>Eine flexible, leistungsfähige, serverseitige Anwendung zum Abspielen von Musik</de>
   <el>Ευέλικτη, ισχυρή εφαρμογή διακομιστή για αναπαραγωγή μουσικής</el>
   <en>a flexible, powerful, server-side application for playing music</en>
   <es_ES>Servidor de reproducción de música flexible y potente</es_ES>
   <es>Servidor de reproducción de música flexible y potente</es>
   <et>a flexible, powerful, server-side application for playing music</et>
   <eu>a flexible, powerful, server-side application for playing music</eu>
   <fa>a flexible, powerful, server-side application for playing music</fa>
   <fil_PH>a flexible, powerful, server-side application for playing music</fil_PH>
   <fi>joustava, tehokas, palvelinpuolen sovellus musiikinsoittamiseen</fi>
   <fr_BE>a flexible, powerful, server-side application for playing music</fr_BE>
   <fr>Une application server-side souple et puissante pour lire de la musique</fr>
   <gl_ES>Aplicativo de servidor, flexible e poderosa, para reprodución de música</gl_ES>
   <gu>a flexible, powerful, server-side application for playing music</gu>
   <he_IL>a flexible, powerful, server-side application for playing music</he_IL>
   <hi>a flexible, powerful, server-side application for playing music</hi>
   <hr>a flexible, powerful, server-side application for playing music</hr>
   <hu>a flexible, powerful, server-side application for playing music</hu>
   <id>a flexible, powerful, server-side application for playing music</id>
   <is>a flexible, powerful, server-side application for playing music</is>
   <it>è un'applicazione lato server, flessibile e potente, per la la riproduzione di file musicali</it>
   <ja>音楽を再生用の柔軟で強力なサーバーサイド・アプリケーション</ja>
   <kk>a flexible, powerful, server-side application for playing music</kk>
   <ko>a flexible, powerful, server-side application for playing music</ko>
   <lt>a flexible, powerful, server-side application for playing music</lt>
   <mk>a flexible, powerful, server-side application for playing music</mk>
   <mr>a flexible, powerful, server-side application for playing music</mr>
   <nb_NO>a flexible, powerful, server-side application for playing music</nb_NO>
   <nb>fleksibel og kraftig lydavspiller på tjenersiden</nb>
   <nl_BE>a flexible, powerful, server-side application for playing music</nl_BE>
   <nl>een flexibele, krachtige applicatie aan de serverzijde voor het afspelen van muziek</nl>
   <pl>elastyczna, potężna aplikacja po stronie serwera do odtwarzania muzyki</pl>
   <pt_BR>Aplicativo flexível e poderoso do lado do servidor para reproduzir música</pt_BR>
   <pt>Aplicação de servidor, flexível e poderosa, para reprodução de música</pt>
   <ro>a flexible, powerful, server-side application for playing music</ro>
   <ru>Гибкое многофункциональное приложение для воспроизведения музыки</ru>
   <sk>a flexible, powerful, server-side application for playing music</sk>
   <sl>Prilagodljiv in zmogljiv strežniški program za predvajanje glasbe</sl>
   <sq>a flexible, powerful, server-side application for playing music</sq>
   <sr>a flexible, powerful, server-side application for playing music</sr>
   <sv>en flexibel, kraftfull server-applikation för att spela upp musik</sv>
   <th>a flexible, powerful, server-side application for playing music</th>
   <tr>müzik çalmak için esnek, güçlü, sunucu taraflı bir uygulama</tr>
   <uk>гнучка. потужна програма на боці сервера для програвання музики</uk>
   <vi>a flexible, powerful, server-side application for playing music</vi>
   <zh_CN>a flexible, powerful, server-side application for playing music</zh_CN>
   <zh_HK>a flexible, powerful, server-side application for playing music</zh_HK>
   <zh_TW>a flexible, powerful, server-side application for playing music</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
mpd
mpc
mpdscribble
ncmpcpp
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
mpd
mpc
mpdscribble
ncmpcpp
</uninstall_package_names>
</app>
